==> hgu133b.db_2.2.0.tar.gz: hgu133b.db/man/hgu133b_dbconn.Rd <==
\name{hgu133b_dbconn}

\alias{hgu133b_dbconn}
\alias{hgu133b_dbfile}
\alias{hgu133b_dbschema}
\alias{hgu133b_dbInfo}


\title{Collect information about the package annotation DB}

\description{
  Some convenience functions for getting a connection object to (or collecting
  information about) the package annotation DB.
}

\usage{
  hgu133b_dbconn()
  hgu133b_dbfile()
  hgu133b_dbschema(file="", show.indices=FALSE)
  hgu133b_dbInfo()
}

\arguments{
  \item{file}{
    A connection, or a character string naming the file to print to (see
    the \code{file} argument of the \code{\link[base]{cat}} function for
    the details).
  }
  \item{show.indices}{
    The CREATE INDEX statements are not shown by default.
    Use \code{show.indices=TRUE} to get them.
  }
}

\details{
  \code{hgu133b_dbconn} returns a connection object to the package
  annotation DB.
  IMPORTANT: Don't call \code{\link[DBI]{dbDisconnect}} on the connection
  object returned by \code{hgu133b_dbconn} or you will
  break all the \code{\link[AnnotationDbi]{AnnDbObj}} objects defined in this package!

  \code{hgu133b_dbfile} returns the path (character string) to the
  package annotation DB (this is an SQLite file).

  \code{hgu133b_dbschema} prints the schema definition of the
  package annotation DB.

  \code{hgu133b_dbInfo} prints other information about the package
  annotation DB.
}

\value{
  \code{hgu133b_dbconn}: a DBIConnection object representing an open
  connection to the package annotation DB.

  \code{hgu133b_dbfile}: a character string with the path to the
  package annotation DB.

  \code{hgu133b_dbschema}: none (invisible \code{NULL}).

  \code{hgu133b_dbInfo}: none (invisible \code{NULL}).
}

\seealso{
  \code{\link[DBI]{dbGetQuery}},
  \code{\link[DBI]{dbConnect}},
  \code{\link[AnnotationDbi]{dbconn}},
  \code{\link[AnnotationDbi]{dbfile}},
  \code{\link[AnnotationDbi]{dbschema}},
  \code{\link[AnnotationDbi]{dbInfo}}
}

\examples{
  ## Count the number of rows in the "probes" table:
  dbGetQuery(hgu133b_dbconn(), "SELECT COUNT(*) FROM probes")

  ## The connection object returned by hgu133b_dbconn() was created with:
  dbConnect(SQLite(), dbname=hgu133b_dbfile(), cache_size=64000, synchronous=0)

  hgu133b_dbschema()

  hgu133b_dbInfo()
}

\keyword{utilities}
\keyword{datasets}

==> hgu133b.db_2.14.0.tar.gz: hgu133b.db/man/hgu133b_dbconn.Rd <==

\name{hgu133b_dbconn}

\alias{hgu133b_dbconn}
\alias{hgu133b_dbfile}
\alias{hgu133b_dbschema}
\alias{hgu133b_dbInfo}


\title{Collect information about the package annotation DB}

\description{
  Some convenience functions for getting a connection object to (or collecting
  information about) the package annotation DB.
}

\usage{
  hgu133b_dbconn()
  hgu133b_dbfile()
  hgu133b_dbschema(file="", show.indices=FALSE)
  hgu133b_dbInfo()
}

\arguments{
  \item{file}{
    A connection, or a character string naming the file to print to (see
    the \code{file} argument of the \code{\link[base]{cat}} function for
    the details).
  }
  \item{show.indices}{
    The CREATE INDEX statements are not shown by default.
    Use \code{show.indices=TRUE} to get them.
  }
}

\details{
  \code{hgu133b_dbconn} returns a connection object to the
  package annotation DB.  IMPORTANT: Don't call
  \code{\link[DBI:dbConnect]{dbDisconnect}} on the connection object
  returned by \code{hgu133b_dbconn} or you will break all the
  \code{\link[AnnotationDbi:AnnDbObj-class]{AnnDbObj}} objects defined
  in this package!

  \code{hgu133b_dbfile} returns the path (character string) to the
  package annotation DB (this is an SQLite file).

  \code{hgu133b_dbschema} prints the schema definition of the
  package annotation DB.

  \code{hgu133b_dbInfo} prints other information about the package
  annotation DB.
}

\value{
  \code{hgu133b_dbconn}: a DBIConnection object representing an
  open connection to the package annotation DB.

  \code{hgu133b_dbfile}: a character string with the path to the
  package annotation DB.

  \code{hgu133b_dbschema}: none (invisible \code{NULL}).

  \code{hgu133b_dbInfo}: none (invisible \code{NULL}).
}

\seealso{
  \code{\link[DBI:dbSendQuery]{dbGetQuery}},
  \code{\link[DBI:dbConnect]{dbConnect}},
  \code{\link[AnnotationDbi:AnnDbObj-class]{dbconn}},
  \code{\link[AnnotationDbi:AnnDbObj-class]{dbfile}},
  \code{\link[AnnotationDbi:AnnDbObj-class]{dbschema}},
  \code{\link[AnnotationDbi:AnnDbObj-class]{dbInfo}}
}

\examples{
  ## Count the number of rows in the "probes" table:
  dbGetQuery(hgu133b_dbconn(), "SELECT COUNT(*) FROM probes")

  ## The connection object returned by hgu133b_dbconn() was
  ## created with:
  dbConnect(SQLite(), dbname=hgu133b_dbfile(), cache_size=64000,
  synchronous=0)

  hgu133b_dbschema()

  hgu133b_dbInfo()
}

\keyword{utilities}
\keyword{datasets}
